@@ -172,6 +172,90 @@ def list_api_tokens(
     )
 
 
+@router.get(
+    "/auth/permissions",
+    summary="Lists permissions for given resource.",
+    operation_id=CoreOperations.LIST_RESOURCE_PERMISSIONS.value,
+    status_code=status.HTTP_200_OK,
+    response_model=List[str],
+)
+def list_resource_permissions(
+    resource_name: str,
+    resolve_roles: bool = True,
+    use_cache: bool = True,
+    token: str = Depends(get_api_token),
+    component_manager: ComponentManager = Depends(get_component_manager),
+) -> Any:
+    """Lists the permissions for a given resource, admin access for that resource is required."""
+    component_manager.verify_access(token, resource_name, AccessLevel.ADMIN)
+
+    return component_manager.get_auth_manager().list_permissions(
+        resource_name, resolve_roles, use_cache
+    )
+
+
+@router.post(
+    "/auth/permissions",
+    summary="Add permission to specified resource.",
+    operation_id=CoreOperations.SET_RESOURCE_PERMISSIONS.value,
+    status_code=status.HTTP_204_NO_CONTENT,
+)
+def add_resource_permission(
+    resource_name: str,
+    permission: str,
+    token: str = Depends(get_api_token),
+    component_manager: ComponentManager = Depends(get_component_manager),
+) -> Any:
+    """Adds permission to specified resource, admin access to the /auth/permissions resource is required."""
+    component_manager.verify_access(token, "/auth/permissions", AccessLevel.ADMIN)
+
+    component_manager.get_auth_manager().add_permission(resource_name, permission)
+    return Response(status_code=status.HTTP_204_NO_CONTENT)
+
+
+@router.delete(
+    "/auth/permissions",
+    summary="Deletes permission of specified resource.",
+    operation_id=CoreOperations.DELETE_RESOURCE_PERMISSIONS.value,
+    status_code=status.HTTP_204_NO_CONTENT,
+)
+def delete_resource_permissions(
+    resource_name: str,
+    permission: str,
+    remove_sub_permissions: bool = False,
+    token: str = Depends(get_api_token),
+    component_manager: ComponentManager = Depends(get_component_manager),
+) -> Any:
+    """Deletes permission of specified resource, admin access to the /auth/permissions resource is required."""
+    component_manager.verify_access(token, "/auth/permissions", AccessLevel.ADMIN)
+
+    component_manager.get_auth_manager().remove_permission(
+        resource_name, permission, remove_sub_permissions
+    )
+    return Response(status_code=status.HTTP_204_NO_CONTENT)
+
+
+@router.get(
+    "/auth/resources",
+    summary="List all resources that have a certain permission.",
+    operation_id=CoreOperations.GET_RESOURCES_WITH_PERMISSION.value,
+    status_code=status.HTTP_200_OK,
+    response_model=List[str],
+)
+def list_resources_with_permission(
+    permission: str,
+    resource_name_prefix: str,
+    token: str = Depends(get_api_token),
+    component_manager: ComponentManager = Depends(get_component_manager),
+) -> Any:
+    """List all resources that have a certain permission, admin access to the /auth/resources resource is required."""
+    component_manager.verify_access(token, "/auth/resources", AccessLevel.ADMIN)
+
+    component_manager.get_auth_manager().list_resources_with_permission(
+        permission, resource_name_prefix
+    )
+
+
 @router.post(
     "/auth/tokens",
     operation_id=CoreOperations.CREATE_TOKEN.value,
@@ -184,6 +268,7 @@ def create_token(
     scopes: Optional[List[str]] = Query(
         None,
         title="Scopes",
+        alias="scope",
         description="Scopes requested for this token. If none specified, the token will be generated with same set of scopes as the authorized token.",
     ),
     token_type: TokenType = Query(
@@ -212,11 +297,6 @@ def create_token(
     """
     authorized_access = component_manager.verify_access(token)
 
-    # Check if the caller has admin access on the user resource
-    component_manager.verify_access(
-        token, authorized_access.authorized_subject, AccessLevel.ADMIN
-    )
-
     if not scopes:
         # Get scopes from token
         scopes = []
@@ -226,6 +306,11 @@ def create_token(
         if token_introspection.scope:
             scopes = token_introspection.scope.split()
 
+    # Check that caller has requested scopes/permissions
+    for scope in scopes:
+        resource_name, access_level = auth_utils.parse_permission(scope)
+        component_manager.verify_access(token, resource_name, access_level)
+
     return component_manager.get_auth_manager().create_token(
         token_subject=authorized_access.authorized_subject,
         scopes=scopes,
@@ -375,6 +460,7 @@ def revoke_token(
 
     This endpoint implements the OAuth2 Revocation Flow ([RFC7009](https://tools.ietf.org/html/rfc7009)).
     """
+    # TODO: Implement authentication required by spec
     component_manager.get_auth_manager().revoke_token(token)
 
 
@@ -403,6 +489,7 @@ def introspect_token(
 
     This endpoint implements the [OAuth2 Introspection Flow](https://www.oauth.com/oauth2-servers/token-introspection-endpoint/) ([RFC7662](https://tools.ietf.org/html/rfc7662)).
     """
+    # TODO: Implement authentication required by spec
     return component_manager.get_auth_manager().introspect_token(token)
 
 
