@@ -4,7 +4,6 @@ from typing import Any, List, Literal, Optional
 import docker
 from loguru import logger
 
-from contaxy.managers.auth import AuthManager
 from contaxy.managers.deployment.docker_utils import (
     create_container_config,
     delete_container,
@@ -18,44 +17,22 @@ from contaxy.managers.deployment.docker_utils import (
     reconnect_to_all_networks,
     wait_for_container,
 )
-from contaxy.managers.deployment.utils import Labels, split_image_name_and_tag
-from contaxy.managers.system import SystemManager
-from contaxy.operations import DeploymentOperations
 from contaxy.schema import Job, JobInput, ResourceAction, Service, ServiceInput
 from contaxy.schema.deployment import DeploymentType, ServiceUpdate
 from contaxy.schema.exceptions import ClientBaseError, ClientValueError
-from contaxy.utils.auth_utils import parse_userid_from_resource_name
-from contaxy.utils.state_utils import GlobalState, RequestState
 
 
-class DockerDeploymentManager(DeploymentOperations):
+class DockerDeploymentPlatform:
     _is_initialized = False
 
-    def __init__(
-        self,
-        global_state: GlobalState,
-        request_state: RequestState,
-        system_manager: SystemManager,
-        auth_manager: AuthManager,
-    ):
-        """Initializes the docker deployment manager.
-
-        Args:
-            global_state: The global state of the app instance.
-            request_state: The state for the current request.
-            system_manager: The system manager used for getting the list of allowed images.
-            auth_manager: The auth manager is used to generate api tokens that a passed to services and jobs.
-        """
-        self.global_state = global_state
-        self.request_state = request_state
-        self._system_manager = system_manager
-        self._auth_manager = auth_manager
+    def __init__(self) -> None:
+        """Initializes the docker deployment manager."""
 
         self.client = docker.from_env()
         # Reconnect the backend to all existing docker networks on startup
-        if not DockerDeploymentManager._is_initialized:
+        if not DockerDeploymentPlatform._is_initialized:
             reconnect_to_all_networks(self.client)
-            DockerDeploymentManager._is_initialized = True
+            DockerDeploymentPlatform._is_initialized = True
 
     def list_services(
         self,
@@ -78,24 +55,14 @@ class DockerDeploymentManager(DeploymentOperations):
     def deploy_service(
         self,
         project_id: str,
-        service: ServiceInput,
+        service: Service,
         action_id: Optional[str] = None,
-        deployment_type: Literal[
-            DeploymentType.SERVICE, DeploymentType.EXTENSION
-        ] = DeploymentType.SERVICE,
         wait: bool = False,
     ) -> Service:
-        image_name, image_tag = split_image_name_and_tag(service.container_image)
-        self._system_manager.check_image(image_name, image_tag)
         container_config = create_container_config(
-            service=service,
+            deployment=service,
             project_id=project_id,
-            auth_manager=self._auth_manager,
-            user_id=parse_userid_from_resource_name(
-                self.request_state.authorized_subject
-            ),
         )
-        container_config["labels"][Labels.DEPLOYMENT_TYPE.value] = deployment_type.value
         handle_network(client=self.client, project_id=project_id)
 
         try:
@@ -127,6 +94,10 @@ class DockerDeploymentManager(DeploymentOperations):
         # Service update is only implemented on DeploymentManagerWithDB wrapper
         raise NotImplementedError()
 
+    def update_service_access(self, project_id: str, service_id: str) -> None:
+        # Service update is only implemented on DeploymentManagerWithDB wrapper
+        raise NotImplementedError()
+
     def delete_service(
         self, project_id: str, service_id: str, delete_volumes: bool = False
     ) -> None:
@@ -165,23 +136,14 @@ class DockerDeploymentManager(DeploymentOperations):
     def deploy_job(
         self,
         project_id: str,
-        job: JobInput,
+        job: Job,
         action_id: Optional[str] = None,
         wait: bool = False,
     ) -> Job:
-        image_name, image_tag = split_image_name_and_tag(job.container_image)
-        self._system_manager.check_image(image_name, image_tag)
         container_config = create_container_config(
-            service=job,
+            deployment=job,
             project_id=project_id,
-            auth_manager=self._auth_manager,
-            user_id=parse_userid_from_resource_name(
-                self.request_state.authorized_subject
-            ),
         )
-        container_config["labels"][
-            Labels.DEPLOYMENT_TYPE.value
-        ] = DeploymentType.JOB.value
         handle_network(client=self.client, project_id=project_id)
 
         try:
