@@ -9,27 +9,22 @@ import psutil
 from loguru import logger
 
 from contaxy.config import settings
-from contaxy.managers.auth import AuthManager
 from contaxy.managers.deployment.utils import (
     _MIN_MEMORY_DEFAULT_MB,
     DEFAULT_DEPLOYMENT_ACTION_ID,
     NO_LOGS_MESSAGE,
     Labels,
-    clean_labels,
-    get_default_environment_variables,
-    get_deployment_id,
     get_gpu_info,
     get_label_string,
     get_network_name,
     get_project_selection_labels,
-    get_template_mapping,
     get_volume_name,
-    map_endpoints_to_endpoints_label,
     map_labels,
-    replace_templates,
+    map_list_to_string,
 )
 from contaxy.schema import ResourceAction
 from contaxy.schema.deployment import (
+    Deployment,
     DeploymentCompute,
     DeploymentStatus,
     DeploymentType,
@@ -40,13 +35,14 @@ from contaxy.schema.deployment import (
 )
 from contaxy.schema.exceptions import (
     ClientBaseError,
-    ClientValueError,
     ResourceNotFoundError,
     ServerBaseError,
 )
 
 # we create networks in the range of 172.33-255.0.0/24
 # Docker by default uses the range 172.17-32.0.0, so we should be save using that range
+from contaxy.utils.utils import remove_none_values_from_dict
+
 INITIAL_CIDR_FIRST_OCTET = 10
 INITIAL_CIDR_SECOND_OCTET = 0
 INITIAL_CIDR = f"{INITIAL_CIDR_FIRST_OCTET}.{INITIAL_CIDR_SECOND_OCTET}.0.0/24"
@@ -66,7 +62,7 @@ def map_container(
         max_cpus=host_config["NanoCpus"] / 1e9,
         max_memory=host_config["Memory"] / 1000 / 1000,
         max_gpus=None,  # TODO: fill with sensible information - where to get it from?
-        min_lifetime=mapped_labels.min_lifetime,
+        min_lifetime=mapped_labels.min_lifetime or 0,
         volume_path=mapped_labels.volume_path,
         # TODO: add max_volume_size, max_replicas
     )
@@ -130,11 +126,14 @@ def map_service(
     container: docker.models.containers.Container,
 ) -> Service:
     transformed_container = map_container(container=container)
+    transformed_container = remove_none_values_from_dict(transformed_container)
+
     return Service(**transformed_container)
 
 
 def map_job(container: docker.models.containers.Container) -> Job:
     transformed_container = map_container(container=container)
+    transformed_container = remove_none_values_from_dict(transformed_container)
     return Job(**transformed_container)
 
 
@@ -319,7 +318,7 @@ def get_project_container(
         project_id=project_id, deployment_type=deployment_type
     )
     labels.append(
-        get_label_string(Labels.DEPLOYMENT_NAME.value, deployment_id),
+        get_label_string(Labels.DEPLOYMENT_ID.value, deployment_id),
     )
     try:
         containers = client.containers.list(all=True, filters={"label": labels})
@@ -445,7 +444,7 @@ def define_mounts(
                 labels={
                     Labels.NAMESPACE.value: settings.SYSTEM_NAMESPACE,
                     Labels.PROJECT_NAME.value: project_id,
-                    Labels.DEPLOYMENT_NAME.value: container_name,
+                    Labels.DEPLOYMENT_ID.value: container_name,
                 },
                 type=mount_type,
             )
@@ -455,15 +454,10 @@ def define_mounts(
 
 
 def create_container_config(
-    service: Union[JobInput, ServiceInput],
+    deployment: Deployment,
     project_id: str,
-    auth_manager: AuthManager,
-    user_id: Optional[str] = None,
 ) -> Dict[str, Any]:
-    if service.display_name is None:
-        raise ClientValueError("Service display_name not defined")
-
-    compute_resources = service.compute or DeploymentCompute()
+    compute_resources = deployment.compute
     (
         min_cpus,
         min_memory,
@@ -474,16 +468,6 @@ def create_container_config(
         min_memory=min_memory,
         min_gpus=min_gpus,
     )
-
-    deployment_type = (
-        DeploymentType.SERVICE if type(service) == ServiceInput else DeploymentType.JOB
-    )
-    container_name = get_deployment_id(
-        project_id,
-        deployment_name=service.display_name,
-        deployment_type=deployment_type,
-    )
-
     max_cpus = (
         compute_resources.max_cpus if compute_resources.max_cpus is not None else 1
     )
@@ -495,61 +479,31 @@ def create_container_config(
     # With regards to memory, Docker requires at least 6MB for a container
     mem_limit = f"{max(_MIN_MEMORY_DEFAULT_MB, min(max_memory, system_memory_in_mb))}MB"
 
+    container_name = deployment.id
     mounts = define_mounts(
         project_id=project_id,
         container_name=container_name,
         compute_resources=compute_resources,
-        service_requirements=service.requirements,
+        service_requirements=deployment.requirements,
     )
 
-    environment = service.parameters or {}
-    # The user MUST not be able to manually set (which) GPUs to use
-    if "NVIDIA_VISIBLE_DEVICES" in environment:
-        del environment["NVIDIA_VISIBLE_DEVICES"]
-    environment = {
-        **environment,
-        **get_default_environment_variables(
-            project_id=project_id,
-            deployment_id=container_name,
-            auth_manager=auth_manager,
-            endpoints=service.endpoints,
-            compute_resources=compute_resources,
-        ),
-    }
-    environment = replace_templates(
-        environment,
-        get_template_mapping(
-            project_id=project_id, user_id=user_id, environment=environment
-        ),
-    )
-
-    min_lifetime = (
-        compute_resources.min_lifetime
-        if compute_resources.min_lifetime is not None
-        else "0"
-    )
-
-    endpoints_label = map_endpoints_to_endpoints_label(service.endpoints)
-    requirements_label = (
-        ",".join(service.requirements) if service.requirements else None
-    )
-    metadata = clean_labels(service.metadata)
     return {
-        "image": service.container_image,
-        "entrypoint": service.command,
-        "command": service.args,
+        "image": deployment.container_image,
+        "entrypoint": deployment.command,
+        "command": deployment.args,
         "detach": True,
-        "environment": environment,
+        "environment": deployment.parameters,
         "labels": {
-            Labels.DISPLAY_NAME.value: service.display_name,
-            Labels.NAMESPACE.value: settings.SYSTEM_NAMESPACE,
-            Labels.MIN_LIFETIME.value: str(min_lifetime),
-            Labels.PROJECT_NAME.value: project_id,
-            Labels.DEPLOYMENT_NAME.value: container_name,
-            Labels.ENDPOINTS.value: endpoints_label,
-            Labels.REQUIREMENTS.value: requirements_label,
-            Labels.CREATED_BY.value: user_id,
-            **metadata,
+            **deployment.metadata,
+            Labels.DISPLAY_NAME.value: deployment.display_name,
+            Labels.DEPLOYMENT_TYPE.value: deployment.deployment_type.value,
+            Labels.DESCRIPTION.value: deployment.description,
+            Labels.ENDPOINTS.value: map_list_to_string(deployment.endpoints),
+            Labels.REQUIREMENTS.value: map_list_to_string(deployment.requirements),
+            Labels.ICON.value: deployment.icon,
+            Labels.MIN_LIFETIME.value: str(compute_resources.min_lifetime),
+            Labels.CREATED_BY.value: deployment.created_by,
+            Labels.VOLUME_PATH.value: compute_resources.volume_path,
         },
         "name": container_name,
         "nano_cpus": int(nano_cpus),
