@@ -1,12 +1,25 @@
+import json
 import time
-from datetime import datetime
-from typing import Dict, List, Literal, Optional
+from datetime import datetime, timezone
+from typing import Dict, List, Literal, Optional, Union
 
 from starlette.responses import Response
 
 from contaxy import config
 from contaxy.config import settings
-from contaxy.operations import DeploymentOperations, JsonDocumentOperations
+from contaxy.managers.deployment.docker import DockerDeploymentPlatform
+from contaxy.managers.deployment.kubernetes import KubernetesDeploymentPlatform
+from contaxy.managers.deployment.utils import (
+    create_deployment_config,
+    split_image_name_and_tag,
+)
+from contaxy.operations import (
+    AuthOperations,
+    DeploymentOperations,
+    JsonDocumentOperations,
+    SystemOperations,
+)
+from contaxy.operations.components import ComponentOperations
 from contaxy.schema import (
     ClientValueError,
     Job,
@@ -34,30 +47,65 @@ def _get_job_collection_id(project_id: str) -> str:
     return f"project_{project_id}_job_metadata"
 
 
-class DeploymentManagerWithDB(DeploymentOperations):
+class DeploymentManager(DeploymentOperations):
     def __init__(
         self,
-        deployment_manager: DeploymentOperations,
-        json_db_manager: JsonDocumentOperations,
+        deployment_platform: Union[
+            DockerDeploymentPlatform, KubernetesDeploymentPlatform
+        ],
+        component_manager: ComponentOperations,
     ):
-        self.deployment_manager = deployment_manager
-        self.json_db = json_db_manager
+        self._global_state = component_manager.global_state
+        self._request_state = component_manager.request_state
+        self.deployment_platform = deployment_platform
+        self._component_manager = component_manager
+
+    @property
+    def _json_db_manager(self) -> JsonDocumentOperations:
+        return self._component_manager.get_json_db_manager()
+
+    @property
+    def _system_manager(self) -> SystemOperations:
+        return self._component_manager.get_system_manager()
+
+    @property
+    def _auth_manager(self) -> AuthOperations:
+        return self._component_manager.get_auth_manager()
 
     def deploy_service(
         self,
         project_id: str,
-        service: ServiceInput,
+        service_input: ServiceInput,
         action_id: Optional[str] = None,
         deployment_type: Literal[
             DeploymentType.SERVICE, DeploymentType.EXTENSION
         ] = DeploymentType.SERVICE,
         wait: bool = False,
     ) -> Service:
-        deployed_service = self.deployment_manager.deploy_service(
-            project_id, service, action_id, deployment_type, wait
+        # Create service in DB
+        db_service = Service(
+            **create_deployment_config(
+                project_id=project_id,
+                deployment_input=service_input,
+                deployment_type=deployment_type,
+                authorized_subject=self._request_state.authorized_subject,
+                system_manager=self._system_manager,
+                auth_manager=self._auth_manager,
+            ).dict()
         )
-        self._create_service_db_document(deployed_service, project_id)
-        return deployed_service
+        self._create_service_db_document(db_service, project_id)
+
+        # Start service container
+        if not service_input.is_stopped:
+            deployed_service = self.deployment_platform.deploy_service(
+                project_id, db_service, action_id, wait
+            )
+            db_service.status = deployed_service.status
+            db_service.internal_id = deployed_service.internal_id
+        else:
+            db_service.status = DeploymentStatus.STOPPED
+            db_service.internal_id = None
+        return db_service
 
     def list_services(
         self,
@@ -66,14 +114,14 @@ class DeploymentManagerWithDB(DeploymentOperations):
             DeploymentType.SERVICE, DeploymentType.EXTENSION
         ] = DeploymentType.SERVICE,
     ) -> List[Service]:
-        service_docs = self.json_db.list_json_documents(
+        service_docs = self._json_db_manager.list_json_documents(
             project_id=config.SYSTEM_INTERNAL_PROJECT,
             collection_id=_get_service_collection_id(project_id),
         )
         # Create lookup for all running services
         deployed_service_lookup: Dict[str, Service] = {
             service.id: service
-            for service in self.deployment_manager.list_services(
+            for service in self.deployment_platform.list_services(
                 project_id, deployment_type
             )
             if service.id is not None
@@ -82,6 +130,8 @@ class DeploymentManagerWithDB(DeploymentOperations):
         # Go through all services in the DB and update their status and internal id
         for service_doc in service_docs:
             db_service = Service.parse_raw(service_doc.json_value)
+            if db_service.deployment_type != deployment_type:
+                continue
             deployed_service = deployed_service_lookup.pop(db_service.id, None)
             if deployed_service is None:
                 db_service.status = DeploymentStatus.STOPPED
@@ -98,7 +148,7 @@ class DeploymentManagerWithDB(DeploymentOperations):
         return services
 
     def _create_service_db_document(self, service: Service, project_id: str) -> None:
-        self.json_db.create_json_document(
+        self._json_db_manager.create_json_document(
             project_id=config.SYSTEM_INTERNAL_PROJECT,
             collection_id=_get_service_collection_id(project_id),
             key=service.id,
@@ -109,7 +159,7 @@ class DeploymentManagerWithDB(DeploymentOperations):
     def get_service_metadata(self, project_id: str, service_id: str) -> Service:
         db_service = self._get_service_from_db(project_id, service_id)
         try:
-            deployed_service = self.deployment_manager.get_service_metadata(
+            deployed_service = self.deployment_platform.get_service_metadata(
                 project_id, db_service.id
             )
             db_service.status = deployed_service.status
@@ -123,9 +173,13 @@ class DeploymentManagerWithDB(DeploymentOperations):
     def update_service(
         self, project_id: str, service_id: str, service: ServiceUpdate
     ) -> Service:
-        if "display_name" in service.dict(exclude_unset=True):
+        service_dict = service.dict(exclude_unset=True)
+        if "display_name" in service_dict:
             raise ClientValueError("Display name of service cannot be updated!")
-        service_doc = self.json_db.update_json_document(
+        if "container_image" in service_dict:
+            image_name, image_tag = split_image_name_and_tag(service.container_image)
+            self._system_manager.check_allowed_image(image_name, image_tag)
+        service_doc = self._json_db_manager.update_json_document(
             project_id=config.SYSTEM_INTERNAL_PROJECT,
             collection_id=_get_service_collection_id(project_id),
             key=service_id,
@@ -144,13 +198,27 @@ class DeploymentManagerWithDB(DeploymentOperations):
 
         return db_service
 
+    def update_service_access(self, project_id: str, service_id: str) -> None:
+        user = self._request_state.authorized_subject
+        self._json_db_manager.update_json_document(
+            project_id=config.SYSTEM_INTERNAL_PROJECT,
+            collection_id=_get_service_collection_id(project_id),
+            key=service_id,
+            json_document=json.dumps(
+                {
+                    "last_access_time": str(datetime.now(timezone.utc)),
+                    "last_access_user": user,
+                }
+            ),
+        )
+
     def delete_service(
         self, project_id: str, service_id: str, delete_volumes: bool = False
     ) -> None:
         db_service = self._get_service_from_db(project_id, service_id)
 
         try:
-            self.deployment_manager.delete_service(
+            self.deployment_platform.delete_service(
                 project_id=project_id,
                 service_id=db_service.id,
                 delete_volumes=delete_volumes,
@@ -159,21 +227,21 @@ class DeploymentManagerWithDB(DeploymentOperations):
             # Workspace is already stopped and service does not exist
             pass
 
-        self.json_db.delete_json_document(
+        self._json_db_manager.delete_json_document(
             project_id=config.SYSTEM_INTERNAL_PROJECT,
             collection_id=_get_service_collection_id(project_id),
             key=db_service.id,
         )
 
     def delete_services(self, project_id: str) -> None:
-        self.deployment_manager.delete_services(project_id)
-        self.json_db.delete_json_collection(
+        self.deployment_platform.delete_services(project_id)
+        self._json_db_manager.delete_json_collection(
             config.SYSTEM_INTERNAL_PROJECT, _get_service_collection_id(project_id)
         )
 
     def _get_service_from_db(self, project_id: str, service_id: str) -> Service:
         try:
-            service_doc = self.json_db.get_json_document(
+            service_doc = self._json_db_manager.get_json_document(
                 project_id=config.SYSTEM_INTERNAL_PROJECT,
                 collection_id=_get_service_collection_id(project_id),
                 key=service_id,
@@ -193,17 +261,17 @@ class DeploymentManagerWithDB(DeploymentOperations):
         lines: Optional[int],
         since: Optional[datetime],
     ) -> str:
-        return self.deployment_manager.get_service_logs(
+        return self.deployment_platform.get_service_logs(
             project_id, service_id, lines, since
         )
 
     def list_jobs(self, project_id: str) -> List[Job]:
-        job_docs = self.json_db.list_json_documents(
+        job_docs = self._json_db_manager.list_json_documents(
             project_id=config.SYSTEM_INTERNAL_PROJECT,
             collection_id=_get_job_collection_id(project_id),
         )
         deployed_job_lookup: Dict[Optional[str], Job] = {
-            job.id: job for job in self.deployment_manager.list_jobs(project_id)
+            job.id: job for job in self.deployment_platform.list_jobs(project_id)
         }
         jobs = []
         for job_doc in job_docs:
@@ -222,26 +290,40 @@ class DeploymentManagerWithDB(DeploymentOperations):
     def deploy_job(
         self,
         project_id: str,
-        job: JobInput,
+        job_input: JobInput,
         action_id: Optional[str] = None,
         wait: bool = False,
     ) -> Job:
-        deployed_job = self.deployment_manager.deploy_job(
-            project_id, job, action_id, wait
+        # Create job in DB
+        db_job = Job(
+            **create_deployment_config(
+                project_id=project_id,
+                deployment_input=job_input,
+                deployment_type=DeploymentType.JOB,
+                authorized_subject=self._request_state.authorized_subject,
+                system_manager=self._system_manager,
+                auth_manager=self._auth_manager,
+            ).dict()
         )
-        self.json_db.create_json_document(
+        self._json_db_manager.create_json_document(
             project_id=config.SYSTEM_INTERNAL_PROJECT,
             collection_id=_get_job_collection_id(project_id),
-            key=deployed_job.id,
-            json_document=deployed_job.json(),
+            key=db_job.id,
+            json_document=db_job.json(),
             upsert=False,
         )
-        return deployed_job
+        # Start job container
+        deployed_job = self.deployment_platform.deploy_job(
+            project_id, db_job, action_id, wait
+        )
+        db_job.status = deployed_job.status
+        db_job.internal_id = deployed_job.internal_id
+        return db_job
 
     def get_job_metadata(self, project_id: str, job_id: str) -> Job:
         db_job = self._get_job_from_db(project_id, job_id)
         try:
-            deployed_job = self.deployment_manager.get_job_metadata(
+            deployed_job = self.deployment_platform.get_job_metadata(
                 project_id, db_job.id
             )
             db_job.status = deployed_job.status
@@ -256,28 +338,28 @@ class DeploymentManagerWithDB(DeploymentOperations):
         db_job = self._get_job_from_db(project_id, job_id)
 
         try:
-            self.deployment_manager.delete_job(
+            self.deployment_platform.delete_job(
                 project_id=project_id,
                 job_id=db_job.id,
             )
         except ResourceNotFoundError:
             pass
 
-        self.json_db.delete_json_document(
+        self._json_db_manager.delete_json_document(
             project_id=config.SYSTEM_INTERNAL_PROJECT,
             collection_id=_get_job_collection_id(project_id),
             key=db_job.id,
         )
 
     def delete_jobs(self, project_id: str) -> None:
-        self.deployment_manager.delete_jobs(project_id)
-        self.json_db.delete_json_collection(
+        self.deployment_platform.delete_jobs(project_id)
+        self._json_db_manager.delete_json_collection(
             config.SYSTEM_INTERNAL_PROJECT, _get_job_collection_id(project_id)
         )
 
     def _get_job_from_db(self, project_id: str, job_id: str) -> Job:
         try:
-            job_doc = self.json_db.get_json_document(
+            job_doc = self._json_db_manager.get_json_document(
                 project_id=config.SYSTEM_INTERNAL_PROJECT,
                 collection_id=_get_job_collection_id(project_id),
                 key=job_id,
@@ -297,7 +379,7 @@ class DeploymentManagerWithDB(DeploymentOperations):
         lines: Optional[int] = None,
         since: Optional[datetime] = None,
     ) -> str:
-        return self.deployment_manager.get_job_logs(project_id, job_id, lines, since)
+        return self.deployment_platform.get_job_logs(project_id, job_id, lines, since)
 
     def execute_service_action(
         self,
@@ -327,9 +409,7 @@ class DeploymentManagerWithDB(DeploymentOperations):
                 f"Action {ACTION_START} on service {service_id} can only be performed "
                 f"when service is stopped but status is {service.status}!"
             )
-        self.deployment_manager.deploy_service(
-            project_id, ServiceInput(**service.dict()), wait=True
-        )
+        self.deployment_platform.deploy_service(project_id, service, wait=True)
 
     def _execute_stop_service_action(self, project_id: str, service_id: str) -> None:
         service = self.get_service_metadata(project_id, service_id)
@@ -338,7 +418,7 @@ class DeploymentManagerWithDB(DeploymentOperations):
                 f"Action {ACTION_STOP} on service {service_id} can only be performed "
                 f"when service is not stopped already!"
             )
-        self.deployment_manager.delete_service(
+        self.deployment_platform.delete_service(
             project_id, service_id, delete_volumes=False
         )
 
@@ -354,13 +434,11 @@ class DeploymentManagerWithDB(DeploymentOperations):
         return self._restart_service(project_id, service)
 
     def _restart_service(self, project_id: str, service: Service) -> Service:
-        self.deployment_manager.delete_service(
+        self.deployment_platform.delete_service(
             project_id, service.id, delete_volumes=False
         )
         self._wait_for_deployment_deletion(project_id, service.id)
-        return self.deployment_manager.deploy_service(
-            project_id, ServiceInput(**service.dict()), wait=True
-        )
+        return self.deployment_platform.deploy_service(project_id, service, wait=True)
 
     def _wait_for_deployment_deletion(
         self, project_id: str, service_id: str, timeout_seconds: int = 60
@@ -368,7 +446,7 @@ class DeploymentManagerWithDB(DeploymentOperations):
         try:
             start_time = time.time()
             while time.time() - start_time < timeout_seconds:
-                self.deployment_manager.get_service_metadata(project_id, service_id)
+                self.deployment_platform.get_service_metadata(project_id, service_id)
                 time.sleep(3)
             raise ServerBaseError(
                 f"Action {ACTION_RESTART} on service {service_id} failed as service "
@@ -438,12 +516,12 @@ class DeploymentManagerWithDB(DeploymentOperations):
     def list_deploy_service_actions(
         self, project_id: str, service: ServiceInput
     ) -> List[ResourceAction]:
-        return self.deployment_manager.list_deploy_service_actions(project_id, service)
+        return self.deployment_platform.list_deploy_service_actions(project_id, service)
 
     def list_deploy_job_actions(
         self, project_id: str, job: JobInput
     ) -> List[ResourceAction]:
-        return self.deployment_manager.list_deploy_job_actions(project_id, job)
+        return self.deployment_platform.list_deploy_job_actions(project_id, job)
 
     def list_job_actions(
         self,
